import 'dart:io';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:itwo_flutter_base/util/util.dart';
import 'package:url_launcher/url_launcher.dart';

class MapUtil {
  static Future<String?> openMapBottomSheet(BuildContext context, {double? longitude, double? latitude, String? address, VoidCallback? toastError}) async {
    if(address!=null){
      await launch('https://ditu.amap.com/search?query=$address');
      return "h5";
    }
    var tencentTocoord = longitude != null && latitude != null ? "&tocoord=$latitude,$longitude" : "";
    var tencentAddressStr = address != null ? "&to=$address" : "";
    String tencentMapUrl =
        'qqmap://map/routeplan?type=drive&fromcoord=CurrentLocation$tencentTocoord&referer=FN4BZ-6E33P-LFTDB-VRZ4C-NTP3Z-RVFFK&debug=true$tencentAddressStr';
    if (Platform.isIOS) tencentMapUrl = Uri.encodeFull(tencentMapUrl);
    bool canTencent = await canLaunch(tencentMapUrl) == true;

    var aMapTocoord = longitude != null && latitude != null ? "&lat=$latitude&lon=$longitude" : "";
    var aMapAddressStr = address != null ? "&poiname=$address" : "";
    String aMapMapUrl = '${Platform.isAndroid ? 'android' : 'ios'}amap://navi?sourceApplication=amap$aMapTocoord&dev=0&style=2$aMapAddressStr';
    if (Platform.isIOS) aMapMapUrl = Uri.encodeFull(aMapMapUrl);
    bool canAMap = await canLaunch(aMapMapUrl) == true;

    var baiduTocoord = longitude != null && latitude != null ? "|latlng:$latitude,$longitude" : "";
    var baiduAddressStr = address != null ? "&destination=$address" : "";
    String baiduMapUrl = 'baidumap://map/direction?coord_type=bd09ll&mode=driving$baiduAddressStr$baiduTocoord';
    if (Platform.isIOS) baiduMapUrl = Uri.encodeFull(baiduMapUrl);
    bool canBaidu = await canLaunch(baiduMapUrl) == true;

    var appleTocoord = longitude != null && latitude != null ? "daddr=$latitude,$longitude" : "";
    var appleAddressStr = address != null ? "&address=$address" : "";
    String appleMapUrl = 'http://maps.apple.com/?$appleTocoord$appleAddressStr';
    if (Platform.isIOS) appleMapUrl = Uri.encodeFull(appleMapUrl);
    bool canApple = Platform.isIOS && await canLaunch(appleMapUrl) == true;

    iLog("canTencent $canTencent canAMap $canAMap canBaidu $canBaidu canApple $canApple");
    if (!canApple && !canAMap && !canBaidu && !canApple) {
      await launch('https://ditu.amap.com/search?query=$address');
      return "h5";
    }
    List<Widget> list = <Widget>[];
    String? action = "";
    if (canTencent) {
      list.add(CupertinoActionSheetAction(child: Text("腾讯地图"), onPressed: () async => action = await _toMap(tencentMapUrl, "tencent")));
    }
    if (canAMap) {
      list.add(CupertinoActionSheetAction(child: Text("高德地图"), onPressed: () async => action = await _toMap(aMapMapUrl, "amap")));
    }
    if (canBaidu) {
      list.add(CupertinoActionSheetAction(child: Text("百度地图"), onPressed: () async => action = await _toMap(baiduMapUrl, "baidu")));
    }
    if (canApple) {
      list.add(CupertinoActionSheetAction(child: Text("苹果地图"), onPressed: () async => action = await _toMap(appleMapUrl, "apple")));
    }
    await showCupertinoModalPopup(context: context, builder: (c) => CupertinoActionSheet(actions: list));
    return action;
  }

  static Future<String?> _toMap(String url, String action) async {
    "url ---> \n $url".log();
    try {
      await launch(url);
      return action;
    } catch (e) {
      print(e);
    }
    return null;
  }
}
